/*
  this sketch contains code from Tom Igoe's State change detection sketch
  http://www.arduino.cc/en/Tutorial/ButtonStateChange,
  Dejan Nedelkovski's Ultrasonic Sensor HC-SR04 and Arduino Tutorial
  www.HowToMechatronics.com,
  and callmeappytechie's https://www.instructables.com/id/Control-Servo-Using-PIR-Sensor/

  Thanks Evan Raskob and Harry Morley.

  Rachel Max - Sept, 2019
  
*/


#include <Adafruit_NeoPixel.h>
#include <math.h>

#define NUMPIXELS  26  // Number of pixels in strand
#define NEOP_PIN 11  // NeoPixels connected to this pin
Adafruit_NeoPixel strip = Adafruit_NeoPixel(NUMPIXELS, NEOP_PIN, NEO_GRB + NEO_KHZ800);


//Distance sensor
long duration;
int distance;
const int trigPin = 2;
const int echoPin = 4;

//signal received LED
const int SIGNAL_LED_PIN = 8;       // LED signals input received

//button
int buttonPushCounter = 0;   // counter for the number of button presses
int buttonState = 0;         // current state of the button
int lastButtonState = 0;     // previous state of the button

//time
unsigned long timeAtLEDon = 0;
long LEDonInterval = 1000.0*60.0*10.0; //1000 milliseconds (1 sec) * seconds in a minute * number of minutes
boolean isOn = false;


void setup() {     

  strip.begin();
  strip.show(); // Initialize all pixels to 'off'

  Serial.begin(9600);

  //Ultrasonic Distance Sensor pins
  pinMode(trigPin, OUTPUT);
  pinMode(echoPin, INPUT);

  //LED Pin to signal imput received 
  pinMode(SIGNAL_LED_PIN, OUTPUT);
}


void loop() {

  //do a quick LED test to show that LEDs work and sketch has been reset
  //made it 3000 so I can get a nice group start up animation
 if (millis() < 3000) {
  colorWipe(strip.Color(148, 0, 211), 30); //purple color
  colorWipe(strip.Color(0, 0, 0), 30);
  }

  //Ultrasonic Distance Sensor
  long duration, distance;
  digitalWrite(trigPin, LOW);//clears trig pin
  delayMicroseconds(2);

  // Sets the trigPin on HIGH state for 10 micro seconds
  digitalWrite(trigPin, HIGH);
  delayMicroseconds(10);
  digitalWrite(trigPin, LOW);

  // Reads the echoPin, returns the sound wave travel time in microseconds
  duration = pulseIn(echoPin, HIGH);
  distance = (duration / 2) / 29.1;

//for debugging
Serial.println(distance);
//distnace is set sort of half way up arm - to be weird 
  if (distance > 18 && distance < 22) {

    buttonState = HIGH;
    digitalWrite(SIGNAL_LED_PIN, HIGH);
  }

  else {
    digitalWrite(SIGNAL_LED_PIN, LOW);
    buttonState = LOW;
  }

  delay(100);

  if (buttonState != lastButtonState) {
    if (buttonState == HIGH) {
      buttonPushCounter++;
      // Serial.println("on");
      Serial.print("number of button pushes: ");
      Serial.println(buttonPushCounter);
    }
  }

  lastButtonState = buttonState;

  //sensor has to be triggered 3 times before light comes on

  if (buttonPushCounter >= 3) {
    for (int i = 0; i <= strip.numPixels() - 1; i++) {
      strip.setPixelColor(i, 148, 0, 211);//purple color
    }
  }

 if (buttonPushCounter == 6) {
    buttonPushCounter = 0;
    for (int i = 0; i <= strip.numPixels() - 1; i++) {
      strip.setPixelColor(i, 0, 0, 0);
    }

  }

  /////////////////////turn off after defined elapsed time if left on/////////////////

  if (!isOn) {
    if (distance > 3 && distance < 8  && buttonPushCounter >= 3) {
      timeAtLEDon = millis();
      isOn = true;
      }
    }
  

  if (millis() > LEDonInterval + timeAtLEDon) {
    for (int i = 0; i <= strip.numPixels() - 1; i++) {
      strip.setPixelColor(i, 0, 0, 0);
     isOn = false;
    }
  }

  strip.show();
  
  }

  // Fill the dots one after the other with a color
void colorWipe(uint32_t c, uint8_t wait) {
  for (uint16_t i = 0; i < strip.numPixels(); i++) {
    strip.setPixelColor(i, c);
    strip.show();
    delay(wait);
  }
}


