/*
  This sketch is based on the LED VU meter for Arduino and Adafruit NeoPixel LEDs.
  Written by Adafruit Industries. Distributed under the BSD license. It also contains 
  code from Tom Igoe's State change detection sketch http://www.arduino.cc/en/Tutorial/ButtonStateChange,

  Thanks Evan Raskob and Harry Morley.

  This is a modifed version of a project I did in Dec 2018. I added an LED animation 
  when lamp is switched on so you know it's ready and an auto-off after 10 minutes in case
  no one yells at it to turn it off.

  Rachel Max - Sept, 2019

pink  #FFC0CB rgb(255,192,203)
lightpink #FFB6C1 rgb(255,182,193)
hotpink #FF69B4 rgb(255,105,180)
deeppink  #FF1493 rgb(255,20,147)
  
*/

#include <Adafruit_NeoPixel.h>
#include <math.h>

#define NUMPIXELS  26  // Number of pixels in strand
#define MIC_PIN   A9  // Microphone is attached to this analog pin
#define LED_PIN    6  // NeoPixel LED strand is connected to this pin
#define SAMPLE_WINDOW   10  // Sample window for average level
#define INPUT_FLOOR 80 //Lower range of analogRead input
#define INPUT_CEILING 1023 //Max range of analogRead input, the lower the value the more sensitive (1023 = max)

//audio
unsigned int sample;
unsigned int minLoud = 600; //make higher for loud room
/* room tone  seems to be about 480-520 */

//time
unsigned long timeAtLEDon = 0;
long LEDonInterval = 1000.0*60.0*10.0; //1000 milliseconds (1 sec) * seconds in a minute * number of minutes
boolean isOn = false;

//button
int buttonPushCounter = 0;   // counter for the number of button presses
int buttonState = 0;         // current state of the button
int lastButtonState = 0;     // previous state of the button


//signal received LED
const int SIGNAL_PIN = 10;       // LED signals input received

Adafruit_NeoPixel strip = Adafruit_NeoPixel(NUMPIXELS, LED_PIN, NEO_GRB + NEO_KHZ800);

void setup()
{
  
  strip.begin();
  strip.show(); // Initialize all pixels to 'off'
  Serial.begin(9600);
  pinMode(SIGNAL_PIN, OUTPUT);
}

void loop() {

  //do a quick LED test to show that LEDs work and sketch has been reset
  //made it 3000 so I can get a nice group start up animation
 if (millis() < 3000) {
  colorWipe(strip.Color(255, 105, 180), 30); //pink
  colorWipe(strip.Color(0, 0, 0), 30);
  }

 
  sample = analogRead(MIC_PIN);
   Serial.println(sample);

  if (sample > minLoud) {
    buttonState = HIGH;
    digitalWrite(SIGNAL_PIN, HIGH);
  }

  else {
    digitalWrite(SIGNAL_PIN, LOW);
    buttonState = LOW;
  }

delay(100);

  if (buttonState != lastButtonState) {
    if (buttonState == HIGH) {
      buttonPushCounter++;
      Serial.print("number of button pushes: ");
      Serial.println(buttonPushCounter);
    }
  }
    
    lastButtonState = buttonState;

    
  //sensor has to be triggered 3 times before light comes on

  if (buttonPushCounter >= 3) {
    for (int i = 0; i <= strip.numPixels() - 1; i++) {
      strip.setPixelColor(i, 255, 105, 180);//pink
    }
  }


 if (buttonPushCounter == 6) {
   for (int i = 0; i <= strip.numPixels() - 1; i++) {
     strip.setPixelColor(i, 0, 0, 0);
       buttonPushCounter = 0;
    }
  }


/////////////////////turn off after defined elapsed time if left on/////////////////

  if (!isOn) {
    if (sample > minLoud && buttonPushCounter >= 3) {
      timeAtLEDon = millis();
      isOn = true;
      }
    }
  

  if (millis() > LEDonInterval + timeAtLEDon) {
    for (int i = 0; i <= strip.numPixels() - 1; i++) {
      strip.setPixelColor(i, 0, 0, 0);
     isOn = false;
    }
  }

  strip.show();

}


// Fill the dots one after the other with a color
void colorWipe(uint32_t c, uint8_t wait) {
  for (uint16_t i = 0; i < strip.numPixels(); i++) {
    strip.setPixelColor(i, c);
    strip.show();
    delay(wait);
  }
}


